@@ -22,7 +22,7 @@ from flashcam import v4lc
 
 from flashcam.mmapwr import mmread_n_clear
 
-
+import os
 
 
 # -----------------------------------------------------------------
@@ -85,6 +85,7 @@ class Camera(BaseCamera):
         global gain_divide,gain_multiply,gain_setdef
         global expo_divide,expo_multiply,expo_setdef
         global timelaps, rotate180
+        global fixed_image # show not camera but image
 
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
@@ -118,6 +119,7 @@ class Camera(BaseCamera):
         expo_setdef =False
 
         rotate180 = False
+        fixed_image = None # just camera.
 
         camera = Camera(  )
         cap, vidnum = camera.init_cam(  )
@@ -210,6 +212,13 @@ class Camera(BaseCamera):
 
             #print("D... ret==", ret)
             if ret: #********************************************************* operations
+                # fixed_image = "beamon.jpg"
+                if not(fixed_image is None):
+                    fullpath_fixed_image = "~/.config/flashcam/"+fixed_image
+                    fullpath_fixed_image = os.path.expanduser( fullpath_fixed_image )
+                    if os.path.exists(fullpath_fixed_image):
+                        frame = cv2.imread( fullpath_fixed_image)
+
                 frame_prev = frame
                 if senh.add_frame(frame):  # it is a proper image....
 
@@ -246,8 +255,6 @@ class Camera(BaseCamera):
                     #--------------------------------------------------------------------------
 
 
-
-
                     # ----------  I need to calculate histogram before labels...
                     if histogram: # just calculate a number on plain frame
                         hmean = senh.histo_mean( )
@@ -256,11 +263,13 @@ class Camera(BaseCamera):
 
                     expression,value = mmread_n_clear( )
                     #print(f"i... expression == {expression}  value == {value}")
+                    # --- fixed_image
                     try:
                         globals()[expression] = eval(value)
                     except:
                         print("X... EXEC FAIL",expression,value)
 
+                    # print("i... fixed:", fixed_image)
                     # print(".... substract_background", substract_background, not(substract_background) )
                     # globals()["substract_background"] = value
 
